summaryrefslogtreecommitdiffstats
path: root/kaddressbook/xxport
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
commit3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (patch)
tree89de88213bd261e4ccaade899ab2d6ec34b3a5a7 /kaddressbook/xxport
parent1dad5f662a09dfc5cc041caffe0f674044a4dcec (diff)
downloadtdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.tar.gz
tdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kaddressbook/xxport')
-rw-r--r--kaddressbook/xxport/csv_xxport.cpp8
-rw-r--r--kaddressbook/xxport/csvimportdialog.cpp42
-rw-r--r--kaddressbook/xxport/gnokii_xxport.cpp160
-rw-r--r--kaddressbook/xxport/kde2_xxport.cpp2
-rw-r--r--kaddressbook/xxport/ldif_xxport.cpp10
-rw-r--r--kaddressbook/xxport/opera_xxport.cpp22
-rw-r--r--kaddressbook/xxport/pab_pablib.cpp4
-rw-r--r--kaddressbook/xxport/pab_xxport.cpp2
-rw-r--r--kaddressbook/xxport/vcard_xxport.cpp36
9 files changed, 143 insertions, 143 deletions
diff --git a/kaddressbook/xxport/csv_xxport.cpp b/kaddressbook/xxport/csv_xxport.cpp
index 22f6afad..9c270a2e 100644
--- a/kaddressbook/xxport/csv_xxport.cpp
+++ b/kaddressbook/xxport/csv_xxport.cpp
@@ -50,7 +50,7 @@ bool CSVXXPort::exportContacts( const KABC::AddresseeList &list, const TQString&
return true;
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
return false;
}
@@ -58,8 +58,8 @@ bool CSVXXPort::exportContacts( const KABC::AddresseeList &list, const TQString&
KTempFile tmpFile;
if ( tmpFile.status() != 0 ) {
TQString txt = i18n( "<qt>Unable to open file <b>%1</b>.%2.</qt>" );
- KMessageBox::error( parentWidget(), txt.tqarg( url.url() )
- .tqarg( strerror( tmpFile.status() ) ) );
+ KMessageBox::error( parentWidget(), txt.arg( url.url() )
+ .arg( strerror( tmpFile.status() ) ) );
return false;
}
@@ -71,7 +71,7 @@ bool CSVXXPort::exportContacts( const KABC::AddresseeList &list, const TQString&
TQFile file( url.path() );
if ( !file.open( IO_WriteOnly ) ) {
TQString txt = i18n( "<qt>Unable to open file <b>%1</b>.</qt>" );
- KMessageBox::error( parentWidget(), txt.tqarg( url.path() ) );
+ KMessageBox::error( parentWidget(), txt.arg( url.path() ) );
return false;
}
diff --git a/kaddressbook/xxport/csvimportdialog.cpp b/kaddressbook/xxport/csvimportdialog.cpp
index 88a2c087..5f24875f 100644
--- a/kaddressbook/xxport/csvimportdialog.cpp
+++ b/kaddressbook/xxport/csvimportdialog.cpp
@@ -24,12 +24,12 @@
#include <tqcheckbox.h>
#include <tqcombobox.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlineedit.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
#include <tqtable.h>
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <tqtooltip.h>
#include <kapplication.h>
@@ -367,7 +367,7 @@ void CSVImportDialog::initGUI()
{
mPage = plainPage();
- TQGridLayout *tqlayout = new TQGridLayout( mPage, 1, 1, marginHint(),
+ TQGridLayout *layout = new TQGridLayout( mPage, 1, 1, marginHint(),
spacingHint() );
TQHBoxLayout *hbox = new TQHBoxLayout();
hbox->setSpacing( spacingHint() );
@@ -379,16 +379,16 @@ void CSVImportDialog::initGUI()
mUrlRequester->setFilter( "*.csv" );
hbox->addWidget( mUrlRequester );
- tqlayout->addMultiCellLayout( hbox, 0, 0, 0, 4 );
+ layout->addMultiCellLayout( hbox, 0, 0, 0, 4 );
// Delimiter: comma, semicolon, tab, space, other
mDelimiterBox = new TQButtonGroup( i18n( "Delimiter" ), mPage );
mDelimiterBox->setColumnLayout( 0, Qt::Vertical );
- mDelimiterBox->tqlayout()->setSpacing( spacingHint() );
- mDelimiterBox->tqlayout()->setMargin( marginHint() );
- TQGridLayout *delimiterLayout = new TQGridLayout( mDelimiterBox->tqlayout() );
- delimiterLayout->tqsetAlignment( TQt::AlignTop );
- tqlayout->addMultiCellWidget( mDelimiterBox, 1, 4, 0, 0 );
+ mDelimiterBox->layout()->setSpacing( spacingHint() );
+ mDelimiterBox->layout()->setMargin( marginHint() );
+ TQGridLayout *delimiterLayout = new TQGridLayout( mDelimiterBox->layout() );
+ delimiterLayout->setAlignment( TQt::AlignTop );
+ layout->addMultiCellWidget( mDelimiterBox, 1, 4, 0, 0 );
mRadioComma = new TQRadioButton( i18n( "Comma" ), mDelimiterBox );
mRadioComma->setChecked( true );
@@ -411,13 +411,13 @@ void CSVImportDialog::initGUI()
mComboLine = new TQComboBox( false, mPage );
mComboLine->insertItem( i18n( "1" ) );
- tqlayout->addWidget( mComboLine, 2, 3 );
+ layout->addWidget( mComboLine, 2, 3 );
mComboQuote = new TQComboBox( false, mPage );
mComboQuote->insertItem( i18n( "\"" ), 0 );
mComboQuote->insertItem( i18n( "'" ), 1 );
mComboQuote->insertItem( i18n( "None" ), 2 );
- tqlayout->addWidget( mComboQuote, 2, 2 );
+ layout->addWidget( mComboQuote, 2, 2 );
mDatePatternEdit = new TQLineEdit( mPage );
mDatePatternEdit->setText( "Y-M-D" ); // ISO 8601 format as default
@@ -427,28 +427,28 @@ void CSVImportDialog::initGUI()
"<li>M: month with 2 digits</li>"
"<li>d: day with 1 or 2 digits</li>"
"<li>D: day with 2 digits</li></ul>" ) );
- tqlayout->addWidget( mDatePatternEdit, 2, 4 );
+ layout->addWidget( mDatePatternEdit, 2, 4 );
label = new TQLabel( i18n( "Start at line:" ), mPage );
- tqlayout->addWidget( label, 1, 3 );
+ layout->addWidget( label, 1, 3 );
label = new TQLabel( i18n( "Textquote:" ), mPage );
- tqlayout->addWidget( label, 1, 2 );
+ layout->addWidget( label, 1, 2 );
label = new TQLabel( i18n( "Date format:" ), mPage );
- tqlayout->addWidget( label, 1, 4 );
+ layout->addWidget( label, 1, 4 );
mIgnoreDuplicates = new TQCheckBox( mPage );
mIgnoreDuplicates->setText( i18n( "Ignore duplicate delimiters" ) );
- tqlayout->addMultiCellWidget( mIgnoreDuplicates, 3, 3, 2, 4 );
+ layout->addMultiCellWidget( mIgnoreDuplicates, 3, 3, 2, 4 );
mCodecCombo = new TQComboBox( mPage );
- tqlayout->addMultiCellWidget( mCodecCombo, 4, 4, 2, 4 );
+ layout->addMultiCellWidget( mCodecCombo, 4, 4, 2, 4 );
mTable = new TQTable( 0, 0, mPage );
mTable->setSelectionMode( TQTable::NoSelection );
mTable->horizontalHeader()->hide();
- tqlayout->addMultiCellWidget( mTable, 5, 5, 0, 4 );
+ layout->addMultiCellWidget( mTable, 5, 5, 0, 4 );
setButtonText( User1, i18n( "Apply Template..." ) );
setButtonText( User2, i18n( "Save Template..." ) );
@@ -503,7 +503,7 @@ void CSVImportDialog::fillTable()
else if ( code == Guess ) {
TQTextCodec* codec = TQTextCodec::codecForContent( mFileArray.data(), mFileArray.size() );
if ( codec ) {
- KMessageBox::information( this, i18n( "Using codec '%1'" ).tqarg( codec->name() ), i18n( "Encoding" ) );
+ KMessageBox::information( this, i18n( "Using codec '%1'" ).arg( codec->name() ), i18n( "Encoding" ) );
inputStream.setCodec( codec );
}
}
@@ -663,7 +663,7 @@ void CSVImportDialog::reloadCodecs()
for ( int i = 0; ( codec = TQTextCodec::codecForIndex( i ) ); i++ )
mCodecs.append( codec );
- mCodecCombo->insertItem( i18n( "Local (%1)" ).tqarg( TQTextCodec::codecForLocale()->name() ), Local );
+ mCodecCombo->insertItem( i18n( "Local (%1)" ).arg( TQTextCodec::codecForLocale()->name() ), Local );
mCodecCombo->insertItem( i18n( "[guess]" ), Guess );
mCodecCombo->insertItem( i18n( "Latin1" ), Latin1 );
mCodecCombo->insertItem( i18n( "Unicode" ), Uni );
@@ -858,7 +858,7 @@ void CSVImportDialog::saveTemplate()
fileName += ".desktop";
if( TQFileInfo(fileName).exists() ) {
- if(KMessageBox::questionYesNo( this, i18n("Do you want to overwrite file \"%1\"").tqarg(fileName) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( this, i18n("Do you want to overwrite file \"%1\"").arg(fileName) ) == KMessageBox::No)
return;
}
TQString name = KInputDialog::getText( i18n( "Template Name" ), i18n( "Please enter a name for the template:" ) );
diff --git a/kaddressbook/xxport/gnokii_xxport.cpp b/kaddressbook/xxport/gnokii_xxport.cpp
index abd3234b..9f7b628f 100644
--- a/kaddressbook/xxport/gnokii_xxport.cpp
+++ b/kaddressbook/xxport/gnokii_xxport.cpp
@@ -63,7 +63,7 @@ extern "C" {
#define GNOKII_CHECK_ERROR(error) \
do { \
if (error) \
- kdError() << TQString("ERROR %1: %2\n").tqarg(error).tqarg(gn_error_print(error));\
+ kdError() << TQString("ERROR %1: %2\n").arg(error).arg(gn_error_print(error));\
} while (0)
// Locale conversion routines:
@@ -126,8 +126,8 @@ static TQString businit(void)
{
GNOKII_DEBUG( "Using new gnokii version." );
- GNOKII_DEBUG( TQString("Compiled with libgnokii version 0x%1\n").tqarg(TQString::number(LIBGNOKII_VERSION,16)) );
- GNOKII_DEBUG( TQString("Using libgnokii runtime version 0x%1\n").tqarg(TQString::number(gn_lib_version(),16)) );
+ GNOKII_DEBUG( TQString("Compiled with libgnokii version 0x%1\n").arg(TQString::number(LIBGNOKII_VERSION,16)) );
+ GNOKII_DEBUG( TQString("Using libgnokii runtime version 0x%1\n").arg(TQString::number(gn_lib_version(),16)) );
gn_error error = gn_lib_phoneprofile_load(NULL, &state);
if (error)
@@ -142,7 +142,7 @@ static TQString businit(void)
"You might try to run \"gnokii --identify\" on the command line to "
"check any cable/transport issues and to verify if your gnokii "
"configuration is correct.</center></qt>")
- .tqarg(gn_error_print(error));
+ .arg(gn_error_print(error));
}
// identify phone
@@ -152,7 +152,7 @@ static TQString businit(void)
imei = gn_lib_get_phone_imei(state);
GNOKII_DEBUG( TQString("Found mobile phone: %1 %2, Revision: %3, IMEI: %4\n")
- .tqarg(manufacturer, model, revision, imei) );
+ .arg(manufacturer, model, revision, imei) );
return TQString();
}
@@ -166,23 +166,23 @@ static gn_error read_phone_memstat( const gn_memory_type memtype, gn_memory_stat
error = gn_lib_addressbook_memstat(state, memtype, &memstat->used, &memstat->free);
GNOKII_DEBUG( TQString("\n\nMobile phone memory status: Type: %1, used=%2, free=%3, total=%4\n\n")
- .tqarg(memtype).tqarg(memstat->used).tqarg(memstat->free).tqarg(memstat->used+memstat->free) );
+ .arg(memtype).arg(memstat->used).arg(memstat->free).arg(memstat->used+memstat->free) );
return error;
}
static TQString buildPhoneInfoString( const gn_memory_status &memstat )
{
- TQString format = TQString::tqfromLatin1("<tr><td><b>%1</b></td><td>%2</td></tr>");
-
- return TQString::tqfromLatin1("<b>%1</b><br><table>%2%3%4%5%6</table><br>")
- .tqarg(i18n("Mobile Phone information:"))
- .tqarg(format.tqarg(i18n("Manufacturer")).tqarg(GN_FROM(manufacturer)))
- .tqarg(format.tqarg(i18n("Phone model")).tqarg(GN_FROM(model)))
- .tqarg(format.tqarg(i18n("Revision")).tqarg(GN_FROM(revision)))
- .tqarg(format.tqarg(i18n("IMEI")).tqarg(GN_FROM(imei)))
- .tqarg(format.tqarg(i18n("Phonebook status"))
- .tqarg(i18n("%1 out of %2 contacts used").tqarg(memstat.used).tqarg(memstat.used+memstat.free)));
+ TQString format = TQString::fromLatin1("<tr><td><b>%1</b></td><td>%2</td></tr>");
+
+ return TQString::fromLatin1("<b>%1</b><br><table>%2%3%4%5%6</table><br>")
+ .arg(i18n("Mobile Phone information:"))
+ .arg(format.arg(i18n("Manufacturer")).arg(GN_FROM(manufacturer)))
+ .arg(format.arg(i18n("Phone model")).arg(GN_FROM(model)))
+ .arg(format.arg(i18n("Revision")).arg(GN_FROM(revision)))
+ .arg(format.arg(i18n("IMEI")).arg(GN_FROM(imei)))
+ .arg(format.arg(i18n("Phonebook status"))
+ .arg(i18n("%1 out of %2 contacts used").arg(memstat.used).arg(memstat.used+memstat.free)));
}
// read and evaluate all phone entries
@@ -209,9 +209,9 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
progress->setTotalSteps(memstat.used);
m_progressDlg->setLabel(i18n("<qt>Importing <b>%1</b> contacts from <b>%2</b> of the Mobile Phone.<br><br>%3</qt>")
- .tqarg(memstat.used)
- .tqarg(gn_memory_type2str(memtype))
- .tqarg(buildPhoneInfoString(memstat)) );
+ .arg(memstat.used)
+ .arg(gn_memory_type2str(memtype))
+ .arg(buildPhoneInfoString(memstat)) );
int num_read = 0;
@@ -233,10 +233,10 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
const char *name = gn_lib_get_pb_name(state);
const char *number = gn_lib_get_pb_number(state);
- GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").tqarg(i)
- .tqarg(GN_FROM(name)).tqarg(GN_FROM(number))
- .tqarg(gn_lib_get_pb_location(state)).tqarg(gn_lib_get_pb_caller_group(state))
- .tqarg(subentries_count));
+ GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").arg(i)
+ .arg(GN_FROM(name)).arg(GN_FROM(number))
+ .arg(gn_lib_get_pb_location(state)).arg(gn_lib_get_pb_caller_group(state))
+ .arg(subentries_count));
KABC::Addressee *a = new KABC::Addressee();
// try to split Name into FamilyName and GivenName
@@ -263,20 +263,20 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
}
a->insertCustom(APP, "X_GSM_CALLERGROUP", s.setNum(gn_lib_get_pb_caller_group(state)));
- a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1%2").tqarg(memtypestr).tqarg(gn_lib_get_pb_location(state)));
+ a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1%2").arg(memtypestr).arg(gn_lib_get_pb_location(state)));
// set ProductId
- a->setProductId(TQString("%1-%2-%3-%4").tqarg(APP).tqarg(model).tqarg(revision).tqarg(imei));
+ a->setProductId(TQString("%1-%2-%3-%4").arg(APP).arg(model).arg(revision).arg(imei));
// evaluate timestamp (ignore timezone)
TQDateTime datetime;
gn_timestamp ts = gn_lib_get_pb_date(state);
if (ts.year<1998)
- datetime = TQDateTime::tqcurrentDateTime();
+ datetime = TQDateTime::currentDateTime();
else
datetime = TQDateTime( TQDate(ts.year, ts.month, ts.day),
TQTime(ts.hour, ts.minute, ts.second) );
- GNOKII_DEBUG(TQString(" date=%1\n").tqarg(datetime.toString()));
+ GNOKII_DEBUG(TQString(" date=%1\n").arg(datetime.toString()));
a->setRevision(datetime);
if (!subentries_count)
@@ -295,7 +295,7 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
TQString s = GN_FROM(number).simplifyWhiteSpace();
GNOKII_DEBUG(TQString(" Subentry#%1, entry_type=%2, number_type=%3, number=%4\n")
- .tqarg(n).tqarg(entry_type).tqarg(number_type).tqarg(s));
+ .arg(n).arg(entry_type).arg(number_type).arg(s));
if (s.isEmpty())
continue;
switch(entry_type) {
@@ -362,7 +362,7 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
break;
default:
GNOKII_DEBUG(TQString(" Not handled id=%1, entry=%2\n")
- .tqarg(entry_type).tqarg(s));
+ .arg(entry_type).arg(s));
break;
} // switch()
} // if(subentry)
@@ -425,8 +425,8 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
time.hour(), time.minute(), time.second(), 0 );
gn_lib_set_pb_date(state, ts);
- GNOKII_DEBUG(TQString("Write #%1: name=%2, number=%3\n").tqarg(phone_location)
- .tqarg(GN_FROM(gn_lib_get_pb_name(state))).tqarg(GN_FROM(gn_lib_get_pb_number(state))));
+ GNOKII_DEBUG(TQString("Write #%1: name=%2, number=%3\n").arg(phone_location)
+ .arg(GN_FROM(gn_lib_get_pb_name(state))).arg(GN_FROM(gn_lib_get_pb_number(state))));
const KABC::Address homeAddr = addr->address(KABC::Address::Home);
const KABC::Address workAddr = addr->address(KABC::Address::Work);
@@ -467,7 +467,7 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
// only one email allowed if we have URLS, notes, addresses (to avoid phone limitations)
if (n && !addr->url().isEmpty() && !addr->note().isEmpty() && addr->addresses().count()) {
GNOKII_DEBUG(TQString(" DROPPED email %1 in favor of URLs, notes and addresses.\n")
- .tqarg(s));
+ .arg(s));
continue;
}
gn_lib_set_pb_subentry(state, -1 /* index to append entry */,
@@ -481,7 +481,7 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
if (Addr->isEmpty()) continue;
TQStringList a;
TQChar sem(';');
- TQString sem_repl(TQString::tqfromLatin1(","));
+ TQString sem_repl(TQString::fromLatin1(","));
a.append( Addr->postOfficeBox().replace( sem, sem_repl ) );
a.append( Addr->extended() .replace( sem, sem_repl ) );
a.append( Addr->street() .replace( sem, sem_repl ) );
@@ -507,8 +507,8 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
const char *number;
gn_lib_get_pb_subentry(state, st, &entry_type, &number_type, &number);
GNOKII_DEBUG(TQString(" SubTel #%1: entry_type=%2, number_type=%3, number=%4\n")
- .tqarg(st).tqarg(entry_type)
- .tqarg(number_type).tqarg(GN_FROM(number)));
+ .arg(st).arg(entry_type)
+ .arg(number_type).arg(GN_FROM(number)));
}
gn_error error = gn_lib_phonebook_write_entry(state, memtype, phone_location);
@@ -656,9 +656,9 @@ bool GNOKIIXXPort::exportContacts( const KABC::AddresseeList &list, const TQStri
m_progressDlg->setButtonText(i18n("&Stop Export"));
m_progressDlg->setLabel(i18n("<qt>Exporting <b>%1</b> contacts to the <b>%2</b> "
"of the Mobile Phone.<br><br>%3</qt>")
- .tqarg(list.count())
- .tqarg(gn_memory_type2str(memtype))
- .tqarg(buildPhoneInfoString(memstat)) );
+ .arg(list.count())
+ .arg(gn_memory_type2str(memtype))
+ .arg(buildPhoneInfoString(memstat)) );
// Now run the loop...
phone_entry_no = 1;
@@ -682,7 +682,7 @@ try_next_phone_entry:
break;
GNOKII_DEBUG(TQString("Try to write entry '%1' at phone_entry_no=%2, phone_count=%3\n")
- .tqarg(addr->realName()).tqarg(phone_entry_no).tqarg(phone_count));
+ .arg(addr->realName()).arg(phone_entry_no).arg(phone_count));
error = GN_ERR_NONE;
@@ -755,7 +755,7 @@ finish:
delete m_progressDlg;
if (!failedList.isEmpty()) {
- GNOKII_DEBUG(TQString("Failed to export: %1\n").tqarg(failedList.join(", ")));
+ GNOKII_DEBUG(TQString("Failed to export: %1\n").arg(failedList.join(", ")));
KMessageBox::informationList(parentWidget(),
i18n("<qt>The following contacts could not be exported to the Mobile Phone. "
"Possible Reasons for this problem could be:<br><ul>"
@@ -801,7 +801,7 @@ static gn_data data;
static void busterminate(void)
{
gn_sm_functions(GN_OP_Terminate, NULL, &state);
- if (lockfile) gn_tqdevice_unlock(lockfile);
+ if (lockfile) gn_device_unlock(lockfile);
}
static TQString businit(void)
@@ -830,7 +830,7 @@ static TQString businit(void)
aux = gn_cfg_get(gn_cfg_info, "global", "use_locking");
// Defaults to 'no'
if (aux && !strcmp(aux, "yes")) {
- lockfile = gn_tqdevice_lock(state.config.port_tqdevice);
+ lockfile = gn_device_lock(state.config.port_device);
if (lockfile == NULL) {
return i18n("Gnokii reports a 'Lock File Error'.\n "
"Please exit all other running instances of gnokii, check if you have "
@@ -851,7 +851,7 @@ static TQString businit(void)
"You might try to run \"gnokii --identify\" on the command line to "
"check any cable/transport issues and to verify if your gnokii "
"configuration is correct.</center></qt>")
- .tqarg(gn_error_print(error));
+ .arg(gn_error_print(error));
}
// identify phone
@@ -874,9 +874,9 @@ static TQString businit(void)
GNOKII_CHECK_ERROR(error);
GNOKII_DEBUG( TQString("Found mobile phone: %1 %2, Revision: %3, IMEI: %4\n")
- .tqarg(manufacturer, model, revision, imei) );
+ .arg(manufacturer, model, revision, imei) );
- PhoneProductId = TQString("%1-%2-%3-%4").tqarg(APP).tqarg(model).tqarg(revision).tqarg(imei);
+ PhoneProductId = TQString("%1-%2-%3-%4").arg(APP).arg(model).arg(revision).arg(imei);
return TQString();
}
@@ -891,7 +891,7 @@ static gn_error read_phone_memstat( const gn_memory_type memtype, gn_memory_stat
memset(memstat, 0, sizeof(*memstat));
memstat->memory_type = memtype;
data.memory_status = memstat;
- error = gn_sm_functions(GN_OP_GetMemorytqStatus, &data, &state);
+ error = gn_sm_functions(GN_OP_GetMemoryStatus, &data, &state);
GNOKII_CHECK_ERROR(error);
if (error != GN_ERR_NONE) {
switch (memtype) {
@@ -908,7 +908,7 @@ static gn_error read_phone_memstat( const gn_memory_type memtype, gn_memory_stat
}
}
GNOKII_DEBUG( TQString("\n\nMobile phone memory status: Type: %1, used=%2, free=%3, total=%4\n\n")
- .tqarg(memtype).tqarg(memstat->used).tqarg(memstat->free).tqarg(memstat->used+memstat->free) );
+ .arg(memtype).arg(memstat->used).arg(memstat->free).arg(memstat->used+memstat->free) );
return error;
}
@@ -943,16 +943,16 @@ static bool phone_entry_empty( const int index, const gn_memory_type memtype )
static TQString buildPhoneInfoString( const gn_memory_status &memstat )
{
- TQString format = TQString::tqfromLatin1("<tr><td><b>%1</b></td><td>%2</td></tr>");
-
- return TQString::tqfromLatin1("<b>%1</b><br><table>%2%3%4%5%6</table><br>")
- .tqarg(i18n("Mobile Phone information:"))
- .tqarg(format.tqarg(i18n("Manufacturer")).tqarg(GN_FROM(manufacturer)))
- .tqarg(format.tqarg(i18n("Phone model")).tqarg(GN_FROM(model)))
- .tqarg(format.tqarg(i18n("Revision")).tqarg(GN_FROM(revision)))
- .tqarg(format.tqarg(i18n("IMEI")).tqarg(GN_FROM(imei)))
- .tqarg(format.tqarg(i18n("Phonebook status"))
- .tqarg(i18n("%1 out of %2 contacts used").tqarg(memstat.used).tqarg(memstat.used+memstat.free)));
+ TQString format = TQString::fromLatin1("<tr><td><b>%1</b></td><td>%2</td></tr>");
+
+ return TQString::fromLatin1("<b>%1</b><br><table>%2%3%4%5%6</table><br>")
+ .arg(i18n("Mobile Phone information:"))
+ .arg(format.arg(i18n("Manufacturer")).arg(GN_FROM(manufacturer)))
+ .arg(format.arg(i18n("Phone model")).arg(GN_FROM(model)))
+ .arg(format.arg(i18n("Revision")).arg(GN_FROM(revision)))
+ .arg(format.arg(i18n("IMEI")).arg(GN_FROM(imei)))
+ .arg(format.arg(i18n("Phonebook status"))
+ .arg(i18n("%1 out of %2 contacts used").arg(memstat.used).arg(memstat.used+memstat.free)));
}
static TQString buildMemoryTypeString( gn_memory_type memtype )
@@ -989,9 +989,9 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
progress->setTotalSteps(memstat.used);
m_progressDlg->setLabel(i18n("<qt>Importing <b>%1</b> contacts from <b>%2</b> of the Mobile Phone.<br><br>%3</qt>")
- .tqarg(memstat.used)
- .tqarg(buildMemoryTypeString(memtype))
- .tqarg(buildPhoneInfoString(memstat)) );
+ .arg(memstat.used)
+ .arg(buildMemoryTypeString(memtype))
+ .arg(buildPhoneInfoString(memstat)) );
int num_read = 0;
@@ -1008,8 +1008,8 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
if (error == GN_ERR_INVALIDMEMORYTYPE)
break;
if (error == GN_ERR_NONE) {
- GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").tqarg(i).tqarg(GN_FROM(entry.name))
- .tqarg(GN_FROM(entry.number)).tqarg(entry.location).tqarg(entry.caller_group).tqarg(entry.subentries_count));
+ GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").arg(i).arg(GN_FROM(entry.name))
+ .arg(GN_FROM(entry.number)).arg(entry.location).arg(entry.caller_group).arg(entry.subentries_count));
KABC::Addressee *a = new KABC::Addressee();
// try to split Name into FamilyName and GivenName
@@ -1036,7 +1036,7 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
}
a->insertCustom(APP, "X_GSM_CALLERGROUP", s.setNum(entry.caller_group));
- a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1%2").tqarg(memtypestr).tqarg(entry.location));
+ a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1%2").arg(memtypestr).arg(entry.location));
// set ProductId
a->setProductId(PhoneProductId);
@@ -1044,11 +1044,11 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
// evaluate timestamp (ignore timezone)
TQDateTime datetime;
if (entry.date.year<1998)
- datetime = TQDateTime::tqcurrentDateTime();
+ datetime = TQDateTime::currentDateTime();
else
datetime = TQDateTime( TQDate(entry.date.year, entry.date.month, entry.date.day),
TQTime(entry.date.hour, entry.date.minute, entry.date.second) );
- GNOKII_DEBUG(TQString(" date=%1\n").tqarg(datetime.toString()));
+ GNOKII_DEBUG(TQString(" date=%1\n").arg(datetime.toString()));
a->setRevision(datetime);
if (!entry.subentries_count)
@@ -1059,8 +1059,8 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
for (int n=0; n<entry.subentries_count; n++) {
TQString s = GN_FROM(entry.subentries[n].data.number).simplifyWhiteSpace();
GNOKII_DEBUG(TQString(" Subentry#%1, entry_type=%2, number_type=%3, number=%4\n")
- .tqarg(n).tqarg(entry.subentries[n].entry_type)
- .tqarg(entry.subentries[n].number_type).tqarg(s));
+ .arg(n).arg(entry.subentries[n].entry_type)
+ .arg(entry.subentries[n].number_type).arg(s));
if (s.isEmpty())
continue;
switch(entry.subentries[n].entry_type) {
@@ -1127,7 +1127,7 @@ static gn_error read_phone_entries( const char *memtypestr, gn_memory_type memty
break;
default:
GNOKII_DEBUG(TQString(" Not handled id=%1, entry=%2\n")
- .tqarg(entry.subentries[n].entry_type).tqarg(s));
+ .arg(entry.subentries[n].entry_type).arg(s));
break;
} // switch()
} // if(subentry)
@@ -1191,8 +1191,8 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
entry.date.minute = time.minute();
entry.date.second = time.second();
- GNOKII_DEBUG(TQString("Write #%1: name=%2, number=%3\n").tqarg(phone_location)
- .tqarg(GN_FROM(entry.name)).tqarg(GN_FROM(entry.number)));
+ GNOKII_DEBUG(TQString("Write #%1: name=%2, number=%3\n").arg(phone_location)
+ .arg(GN_FROM(entry.name)).arg(GN_FROM(entry.number)));
const KABC::Address homeAddr = addr->address(KABC::Address::Home);
const KABC::Address workAddr = addr->address(KABC::Address::Work);
@@ -1244,7 +1244,7 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
// only one email allowed if we have URLS, notes, addresses (to avoid phone limitations)
if (n && !addr->url().isEmpty() && !addr->note().isEmpty() && addr->addresses().count()) {
GNOKII_DEBUG(TQString(" DROPPED email %1 in favor of URLs, notes and addresses.\n")
- .tqarg(s));
+ .arg(s));
continue;
}
subentry->entry_type = GN_PHONEBOOK_ENTRY_Email;
@@ -1263,7 +1263,7 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
subentry->entry_type = GN_PHONEBOOK_ENTRY_Postal;
TQStringList a;
TQChar sem(';');
- TQString sem_repl(TQString::tqfromLatin1(","));
+ TQString sem_repl(TQString::fromLatin1(","));
a.append( Addr->postOfficeBox().replace( sem, sem_repl ) );
a.append( Addr->extended() .replace( sem, sem_repl ) );
a.append( Addr->street() .replace( sem, sem_repl ) );
@@ -1289,8 +1289,8 @@ static gn_error xxport_phone_write_entry( int phone_location, gn_memory_type mem
for (int st=0; st<entry.subentries_count; st++) {
gn_phonebook_subentry *subentry = &entry.subentries[st];
GNOKII_DEBUG(TQString(" SubTel #%1: entry_type=%2, number_type=%3, number=%4\n")
- .tqarg(st).tqarg(subentry->entry_type)
- .tqarg(subentry->number_type).tqarg(GN_FROM(subentry->data.number)));
+ .arg(st).arg(subentry->entry_type)
+ .arg(subentry->number_type).arg(GN_FROM(subentry->data.number)));
}
data.phonebook_entry = &entry;
@@ -1309,7 +1309,7 @@ static gn_error xxport_phone_delete_entry( int phone_location, gn_memory_type me
entry.memory_type = memtype;
entry.location = phone_location;
data.phonebook_entry = &entry;
- GNOKII_DEBUG(TQString("Deleting entry %1\n").tqarg(phone_location));
+ GNOKII_DEBUG(TQString("Deleting entry %1\n").arg(phone_location));
gn_error error = gn_sm_functions(GN_OP_WritePhonebook, &data, &state);
GNOKII_CHECK_ERROR(error);
return error;
@@ -1447,9 +1447,9 @@ bool GNOKIIXXPort::exportContacts( const KABC::AddresseeList &list, const TQStri
m_progressDlg->setButtonText(i18n("&Stop Export"));
m_progressDlg->setLabel(i18n("<qt>Exporting <b>%1</b> contacts to the <b>%2</b> "
"of the Mobile Phone.<br><br>%3</qt>")
- .tqarg(list.count())
- .tqarg(buildMemoryTypeString(memtype))
- .tqarg(buildPhoneInfoString(memstat)) );
+ .arg(list.count())
+ .arg(buildMemoryTypeString(memtype))
+ .arg(buildPhoneInfoString(memstat)) );
// Now run the loop...
phone_entry_no = 1;
@@ -1473,7 +1473,7 @@ try_next_phone_entry:
break;
GNOKII_DEBUG(TQString("Try to write entry '%1' at phone_entry_no=%2, phone_count=%3\n")
- .tqarg(addr->realName()).tqarg(phone_entry_no).tqarg(phone_count));
+ .arg(addr->realName()).arg(phone_entry_no).arg(phone_count));
error = GN_ERR_NONE;
@@ -1546,7 +1546,7 @@ finish:
delete m_progressDlg;
if (!failedList.isEmpty()) {
- GNOKII_DEBUG(TQString("Failed to export: %1\n").tqarg(failedList.join(", ")));
+ GNOKII_DEBUG(TQString("Failed to export: %1\n").arg(failedList.join(", ")));
KMessageBox::informationList(parentWidget(),
i18n("<qt>The following contacts could not be exported to the Mobile Phone. "
"Possible Reasons for this problem could be:<br><ul>"
diff --git a/kaddressbook/xxport/kde2_xxport.cpp b/kaddressbook/xxport/kde2_xxport.cpp
index 3b60ca5e..309bb9b5 100644
--- a/kaddressbook/xxport/kde2_xxport.cpp
+++ b/kaddressbook/xxport/kde2_xxport.cpp
@@ -49,7 +49,7 @@ KABC::AddresseeList KDE2XXPort::importContacts( const TQString& ) const
{
TQString fileName = locateLocal( "data", "kabc/std.vcf" );
if ( !TQFile::exists( fileName ) ) {
- KMessageBox::sorry( parentWidget(), i18n( "<qt>Could not find a KDE 2 address book <b>%1</b>.</qt>" ).tqarg( fileName ) );
+ KMessageBox::sorry( parentWidget(), i18n( "<qt>Could not find a KDE 2 address book <b>%1</b>.</qt>" ).arg( fileName ) );
return KABC::AddresseeList();
}
diff --git a/kaddressbook/xxport/ldif_xxport.cpp b/kaddressbook/xxport/ldif_xxport.cpp
index a51169e7..30718a9f 100644
--- a/kaddressbook/xxport/ldif_xxport.cpp
+++ b/kaddressbook/xxport/ldif_xxport.cpp
@@ -71,7 +71,7 @@ KABC::AddresseeList LDIFXXPort::importContacts( const TQString& ) const
TQFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
TQString msg = i18n( "<qt>Unable to open <b>%1</b> for reading.</qt>" );
- KMessageBox::error( parentWidget(), msg.tqarg( fileName ) );
+ KMessageBox::error( parentWidget(), msg.arg( fileName ) );
return addrList;
}
@@ -97,7 +97,7 @@ bool LDIFXXPort::exportContacts( const KABC::AddresseeList &list, const TQString
return true;
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
return false;
}
@@ -106,8 +106,8 @@ bool LDIFXXPort::exportContacts( const KABC::AddresseeList &list, const TQString
KTempFile tmpFile;
if ( tmpFile.status() != 0 ) {
TQString txt = i18n( "<qt>Unable to open file <b>%1</b>.%2.</qt>" );
- KMessageBox::error( parentWidget(), txt.tqarg( url.url() )
- .tqarg( strerror( tmpFile.status() ) ) );
+ KMessageBox::error( parentWidget(), txt.arg( url.url() )
+ .arg( strerror( tmpFile.status() ) ) );
return false;
}
@@ -121,7 +121,7 @@ bool LDIFXXPort::exportContacts( const KABC::AddresseeList &list, const TQString
if ( !file.open( IO_WriteOnly ) ) {
TQString txt = i18n( "<qt>Unable to open file <b>%1</b>.</qt>" );
- KMessageBox::error( parentWidget(), txt.tqarg( filename ) );
+ KMessageBox::error( parentWidget(), txt.arg( filename ) );
return false;
}
diff --git a/kaddressbook/xxport/opera_xxport.cpp b/kaddressbook/xxport/opera_xxport.cpp
index 4c2949cc..800f11fa 100644
--- a/kaddressbook/xxport/opera_xxport.cpp
+++ b/kaddressbook/xxport/opera_xxport.cpp
@@ -48,14 +48,14 @@ KABC::AddresseeList OperaXXPort::importContacts( const TQString& ) const
{
KABC::AddresseeList addrList;
- TQString fileName = KFileDialog::getOpenFileName( TQDir::homeDirPath() + TQString::tqfromLatin1( "/.opera/contacts.adr" ) );
+ TQString fileName = KFileDialog::getOpenFileName( TQDir::homeDirPath() + TQString::fromLatin1( "/.opera/contacts.adr" ) );
if ( fileName.isEmpty() )
return addrList;
TQFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
TQString msg = i18n( "<qt>Unable to open <b>%1</b> for reading.</qt>" );
- KMessageBox::error( parentWidget(), msg.tqarg( fileName ) );
+ KMessageBox::error( parentWidget(), msg.arg( fileName ) );
return addrList;
}
@@ -70,7 +70,7 @@ KABC::AddresseeList OperaXXPort::importContacts( const TQString& ) const
while ( !stream.atEnd() ) {
line = stream.readLine();
line = line.stripWhiteSpace();
- if ( line == TQString::tqfromLatin1( "#CONTACT" ) ) {
+ if ( line == TQString::fromLatin1( "#CONTACT" ) ) {
parseContact = true;
addr = KABC::Addressee();
continue;
@@ -87,9 +87,9 @@ KABC::AddresseeList OperaXXPort::importContacts( const TQString& ) const
int sep = line.find( '=' );
key = line.left( sep ).lower();
value = line.mid( sep + 1 );
- if ( key == TQString::tqfromLatin1( "name" ) )
+ if ( key == TQString::fromLatin1( "name" ) )
addr.setNameFromString( value );
- else if ( key == TQString::tqfromLatin1( "mail" ) ) {
+ else if ( key == TQString::fromLatin1( "mail" ) ) {
TQStringList emails = TQStringList::split( separator, value );
TQStringList::Iterator it = emails.begin();
@@ -98,20 +98,20 @@ KABC::AddresseeList OperaXXPort::importContacts( const TQString& ) const
addr.insertEmail( *it, preferred );
preferred = false;
}
- } else if ( key == TQString::tqfromLatin1( "phone" ) )
+ } else if ( key == TQString::fromLatin1( "phone" ) )
addr.insertPhoneNumber( KABC::PhoneNumber( value ) );
- else if ( key == TQString::tqfromLatin1( "fax" ) )
+ else if ( key == TQString::fromLatin1( "fax" ) )
addr.insertPhoneNumber( KABC::PhoneNumber( value,
KABC::PhoneNumber::Fax | KABC::PhoneNumber::Home ) );
- else if ( key == TQString::tqfromLatin1( "postaladdress" ) ) {
+ else if ( key == TQString::fromLatin1( "postaladdress" ) ) {
KABC::Address address( KABC::Address::Home );
address.setLabel( value.replace( separator, "\n" ) );
addr.insertAddress( address );
- } else if ( key == TQString::tqfromLatin1( "description" ) )
+ } else if ( key == TQString::fromLatin1( "description" ) )
addr.setNote( value.replace( separator, "\n" ) );
- else if ( key == TQString::tqfromLatin1( "url" ) )
+ else if ( key == TQString::fromLatin1( "url" ) )
addr.setUrl( KURL( value ) );
- else if ( key == TQString::tqfromLatin1( "pictureurl" ) ) {
+ else if ( key == TQString::fromLatin1( "pictureurl" ) ) {
KABC::Picture pic( value );
addr.setPhoto( pic );
}
diff --git a/kaddressbook/xxport/pab_pablib.cpp b/kaddressbook/xxport/pab_pablib.cpp
index 198e683f..344647f6 100644
--- a/kaddressbook/xxport/pab_pablib.cpp
+++ b/kaddressbook/xxport/pab_pablib.cpp
@@ -46,7 +46,7 @@ adr_t A;
bool ret;
if (!in.isOpen()) {TQString msg;
- msg=i18n("Cannot open %1 for reading").tqarg(pabfile);
+ msg=i18n("Cannot open %1 for reading").arg(pabfile);
// info->alert(msg);
return false;
}
@@ -243,7 +243,7 @@ bool pab::knownPAB(void)
content_t id;
id=go(0);
if (id!=PAB_FILE_ID) {TQString msg;
- msg=i18n("%1 has no PAB id that I know of, cannot convert this").tqarg(pabfile);
+ msg=i18n("%1 has no PAB id that I know of, cannot convert this").arg(pabfile);
// info->alert(msg);
return false;
}
diff --git a/kaddressbook/xxport/pab_xxport.cpp b/kaddressbook/xxport/pab_xxport.cpp
index 021f671c..911e92de 100644
--- a/kaddressbook/xxport/pab_xxport.cpp
+++ b/kaddressbook/xxport/pab_xxport.cpp
@@ -55,7 +55,7 @@ KABC::AddresseeList PABXXPort::importContacts( const TQString& ) const
if ( fileName.isEmpty() )
return addrList;
if ( !TQFile::exists( fileName ) ) {
- KMessageBox::sorry( parentWidget(), i18n( "<qt>Could not find a MS Exchange Personal Address Book <b>%1</b>.</qt>" ).tqarg( fileName ) );
+ KMessageBox::sorry( parentWidget(), i18n( "<qt>Could not find a MS Exchange Personal Address Book <b>%1</b>.</qt>" ).arg( fileName ) );
return addrList;
}
diff --git a/kaddressbook/xxport/vcard_xxport.cpp b/kaddressbook/xxport/vcard_xxport.cpp
index e752b905..1e5d7ee9 100644
--- a/kaddressbook/xxport/vcard_xxport.cpp
+++ b/kaddressbook/xxport/vcard_xxport.cpp
@@ -25,7 +25,7 @@
#include <tqfile.h>
#include <tqfont.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpushbutton.h>
#include <kabc/vcardconverter.h>
@@ -237,12 +237,12 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
TQString vCardText;
// With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use tqfromLatin1()
// and hope that are fields are encoded correctly.
- if ( TQString::tqfromLatin1( rawData ).lower().contains( "version:3.0" ) ) {
+ if ( TQString::fromLatin1( rawData ).lower().contains( "version:3.0" ) ) {
vCardText = TQString::fromUtf8( rawData );
} else {
- vCardText = TQString::tqfromLatin1( rawData );
+ vCardText = TQString::fromLatin1( rawData );
}
addrList += parseVCard( vCardText );
}
@@ -250,15 +250,15 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
KIO::NetAccess::removeTempFile( fileName );
} else {
TQString text = i18n( "<qt>When trying to read the vCard, there was an error opening the file '%1': %2</qt>" );
- text = text.tqarg( (*it).url() );
- text = text.tqarg( kapp->translate( "TQFile",
+ text = text.arg( (*it).url() );
+ text = text.arg( kapp->translate( "TQFile",
TQString(file.errorString()).latin1() ) );
KMessageBox::error( parentWidget(), text, caption );
anyFailures = true;
}
} else {
TQString text = i18n( "<qt>Unable to access vCard: %1</qt>" );
- text = text.tqarg( KIO::NetAccess::lastErrorString() );
+ text = text.arg( KIO::NetAccess::lastErrorString() );
KMessageBox::error( parentWidget(), text, caption );
anyFailures = true;
}
@@ -293,7 +293,7 @@ KABC::AddresseeList VCardXXPort::parseVCard( const TQByteArray &data ) const
bool VCardXXPort::doExport( const KURL &url, const TQByteArray &data )
{
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
return false;
}
KTempFile tmpFile;
@@ -315,7 +315,7 @@ KABC::AddresseeList VCardXXPort::parseVCard( const TQString &data ) const
bool VCardXXPort::doExport( const KURL &url, const TQString &data )
{
if( TQFileInfo(url.path()).exists() ) {
- if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").tqarg( url.path()) ) == KMessageBox::No)
+ if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"").arg( url.path()) ) == KMessageBox::No)
return false;
}
KTempFile tmpFile;
@@ -471,18 +471,18 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list,
mContacts( list )
{
TQFrame *page = plainPage();
- TQVBoxLayout *tqlayout = new TQVBoxLayout( page, marginHint(), spacingHint() );
+ TQVBoxLayout *layout = new TQVBoxLayout( page, marginHint(), spacingHint() );
TQLabel *label = new TQLabel( i18n( "Do you want to import this contact in your address book?" ), page );
TQFont font = label->font();
font.setBold( true );
label->setFont( font );
- tqlayout->addWidget( label );
+ layout->addWidget( label );
mView = new KPIM::AddresseeView( page );
mView->enableLinks( 0 );
mView->setVScrollBarMode( TQScrollView::Auto );
- tqlayout->addWidget( mView );
+ layout->addWidget( mView );
setButtonText( Apply, i18n( "Import All..." ) );
@@ -544,22 +544,22 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( TQWidget *parent,
{
TQFrame *page = plainPage();
- TQVBoxLayout *tqlayout = new TQVBoxLayout( page, marginHint(), spacingHint() );
+ TQVBoxLayout *layout = new TQVBoxLayout( page, marginHint(), spacingHint() );
TQLabel *label = new TQLabel( i18n( "Select the fields which shall be exported in the vCard." ), page );
- tqlayout->addWidget( label );
+ layout->addWidget( label );
mPrivateBox = new TQCheckBox( i18n( "Private fields" ), page );
- tqlayout->addWidget( mPrivateBox );
+ layout->addWidget( mPrivateBox );
mBusinessBox = new TQCheckBox( i18n( "Business fields" ), page );
- tqlayout->addWidget( mBusinessBox );
+ layout->addWidget( mBusinessBox );
mOtherBox = new TQCheckBox( i18n( "Other fields" ), page );
- tqlayout->addWidget( mOtherBox );
+ layout->addWidget( mOtherBox );
mEncryptionKeys = new TQCheckBox( i18n( "Encryption keys" ), page );
- tqlayout->addWidget( mEncryptionKeys );
+ layout->addWidget( mEncryptionKeys );
KConfig config( "kaddressbookrc" );
config.setGroup( "XXPortVCard" );
@@ -237,12 +237,12 @@ KABC::AddresseeList VCardXXPort::importContacts( const TQString& ) const
TQString vCardText;
- // With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use tqfromLatin1()
+ // With version 3.0, vCards are encoded with UTF-8 by default. Otherwise, use fromLatin1()
// and hope that are fields are encoded correctly.